function [A,b] = mkp_2d(uzly,prvky,tau,q,f,ID,IN,uD,gN)

% [A,b] = mkp_2d(uzly,prvky,tau,q,f,ID,IN,dataD,dataN)
%           sestavi MKP-soustavu A*u = b, kde
%           uzly ... souradnice diskretizacnich uzlu,
%           prvky ... dvojice indexu uzlu,
%           tau ... vektor hodnot tau(x) pro kazdy prvek,
%           q ... vektor hodnot q(x) pro kazdy prvek,
%           f ... vektor hodnot f(x) pro kazdy prvek,
%           l ... delka intervalu Omega = <0,l>,
%           ID ... vektor indexu Dirichletovych uzlu,
%           IN ... vektor indexu Neumannovych uzlu,
%           uD ... vektor hodnot reseni uD(x) (Dirichlet. podminka)
%           gN ... hodnoty tau(x)*u'(x) v Neumannovych uzlech

n = size(uzly,2);
m = size(prvky,2);
nIN = size(IN,2);

A = zeros(n,n);
b = zeros(n,1);

for i=1:m
    prvek_lok = prvky(:,i);
    uzly_lok = uzly(:,prvek_lok);
    tau_lok = tau(i);
    q_lok = q(i);
    f_lok = f(i);
    uD_lok = uD(prvek_lok);
    
    A_lok = alok_gradgrad(uzly_lok,tau_lok) + alok_idid(uzly_lok,q_lok);
    b_lok = blok_id(uzly_lok,f_lok);
    
    for j=1:3
        for k=1:3
            if j==k || ( ~max(prvek_lok(j)==ID) && ~max(prvek_lok(k)==ID) )
                A(prvek_lok(j),prvek_lok(k)) = A(prvek_lok(j),prvek_lok(k)) + A_lok(j,k);
            end
        end
        if ~max(prvek_lok(j)==ID)
            b(prvek_lok(j)) = b(prvek_lok(j)) + b_lok(j) - A_lok(j,:)*uD_lok;
        end
    end
    
end

for i=1:nIN
    prvek_lok = IN(:,i);
    uzly_lok = uzly(:,prvek_lok);
    gN_lok = gN(i);
    
    b_lok = blok_id_boundary(uzly_lok,gN_lok);
    
    for j=1:2
        if ~max(prvek_lok(j)==ID)
            b(prvek_lok(j)) = b(prvek_lok(j)) + b_lok(j);
        end
    end
end
