function [A,b] = mkp_2d_elektrostatika(uzly,prvky,tau,ID,uD,IGamma,uGamma,rhoGamma)

% [A,b] = mkp_2d_elektrostatika(uzly,prvky,tau,ID,uD,IGamma,uGamma)
%           sestavi MKP-soustavu A*u = b pro
%             -div(tau(x)*grad(u(x)) = 0 v Omega,
%                               u(x) = 0 na hranici Omega,
%                               u(x) = uGamma(x) na rozhrani Gamma,
%           kde
%           uzly ... souradnice diskretizacnich uzlu,
%           prvky ... dvojice indexu uzlu,
%           tau ... vektor hodnot tau(x) pro kazdy prvek,
%           ID ... vektor indexu Dirichletovych uzlu,
%           IGamma ... usecky podel Gamma,
%           uGamma ... vektor hodnot u(x) pro kazdou usecku na Gamma,
%           rhoGamma ... je penalizacni parametr na Gamma.

n = size(uzly,2);
m = size(prvky,2);
nIGamma = size(IGamma,2);

A = zeros(n,n);
b = zeros(n,1);

for i=1:m
    prvek_lok = prvky(:,i);
    uzly_lok = uzly(:,prvek_lok);
    tau_lok = tau(i);
    uD_lok = uD(prvek_lok);
    
    A_lok = alok_gradgrad(uzly_lok,tau_lok);
    b_lok = zeros(3,1);
    
    for j=1:3
        for k=1:3
            if j==k || ( ~max(prvek_lok(j)==ID) && ~max(prvek_lok(k)==ID) )
                A(prvek_lok(j),prvek_lok(k)) = A(prvek_lok(j),prvek_lok(k)) + A_lok(j,k);
            end
        end
        if ~max(prvek_lok(j)==ID)
            b(prvek_lok(j)) = b(prvek_lok(j)) + b_lok(j) - A_lok(j,:)*uD_lok;
        end
    end
    
end

for i=1:nIGamma
    prvek_lok = IGamma(:,i);
    uzly_lok = uzly(:,prvek_lok);
    
    uGamma_lok = uGamma(i);
    
    A_lok = alok_idid_boundary(uzly_lok,rhoGamma);
    b_lok = blok_id_boundary(uzly_lok,rhoGamma*uGamma_lok);
    
    for j=1:2
        for k=1:2
            if j==k || ( ~max(prvek_lok(j)==ID) && ~max(prvek_lok(k)==ID) )
                A(prvek_lok(j),prvek_lok(k)) = A(prvek_lok(j),prvek_lok(k)) + A_lok(j,k);
            end
        end
        if ~max(prvek_lok(j)==ID)
            b(prvek_lok(j)) = b(prvek_lok(j)) + b_lok(j);
        end
    end
end
