function [A,b] = assemble(fce_lame,fce_f,fce_U,fce_g,x,e,ID,IN)

% function [A,b] = assemble(fce_lame,fce_f,fce_U,fce_g,x,e,ID,IN)
%          Sestavi matici (tuhosti) a vektor (zatizeni),
%          ktera vzejde z konecne-prvkove aproximace
%          nasledujici 2d variacni ulohy:
%           Najdi uH z Vh : a(uH,v) = f(v) pro vsechna v z Vh,
%          kde
%           a(v,u) = \int_{Omega} lambda(x)*div(uH(x))*div(v(x)) dx +
%                    + \int_{Omega} mu(x) * \sum_{k,l=1}^3 eps_{k,l}(uH(x))*eps_{k,l}(v(x)) dx,
%           f(v) = \int_{Omega} f(x)*v(x) +
%                  + \int_{Gamma_N} g(x)*v(x) ds -
%                  - \int_{Omega} lambda(x)*div(U(x))*div(v(x)) dx -
%                  - \int_{Omega} mu(x)* sum_{k,l=1}^3 eps_{k,l}(U(x))*eps_{k,l}(v(x)) dx,
%           Vh je dano Lagrangeovymi tvarovymi funkcemi
%           s Dirichletovou okrajovou podminkou u(x) = U(x) na Gamma_D,
%           ktera je urcena indexy uzlu ID,
%           a s Neumannovou okrajovou podminkou sigma(u(x))*n(x) = g(x) na Gamma_N,
%           ktera je urcena indexy uzlu IN,
%           eps_{k,l}(v) = 0.5 * (dv_k/dx_l + dv_l/dx_k).

% pocet uzlu (pocet stupnu volnosti deleno 3)
n = max(size(x));

% pocet elementu
ne = max(size(e));

A = sparse(2*n,2*n);
b = zeros(2*n,1);

for i=1:ne
    ei = e(i,:);
    x1 = x(:,ei(1));
    x2 = x(:,ei(2));
    x3 = x(:,ei(3));
    
    Ri = [x2-x1 x3-x1];
    ri = x1;
    
    massPointi = Ri*[1/3;1/3] + ri;
    
    [lambdai,mui] = feval(fce_lame,massPointi);
    fi = feval(fce_f,massPointi);
    
    [Ui,divUi,epsUi] = feval(fce_U,massPointi);
    
    Aei = alok(lambdai,mui,x,ei);
    bei = blok_f(fi,x,ei) + blok_g(fce_g,IN,x,ei);
    bei = bei + blok_u(lambdai,mui,divUi,epsUi,x,ei);
    
    for i1=1:3
        for j1=1:2
            for i2=1:3
                for j2=1:2
                    if (i1==i2 & j1==j2) | (~in(ID,ei(i1)) & ~in(ID,ei(i2)))
                        index1 = (ei(i1)-1)*2 + j1;
                        lokindex1 = (i1-1)*2 + j1;
                        index2 = (ei(i2)-1)*2 + j2;
                        lokindex2 = (i2-1)*2 + j2;

                        A(index1,index2) = A(index1,index2) + Aei(lokindex1,lokindex2);
                    end
                end
            end
    
            if ~in(ID,ei(i1))
                index1 = (ei(i1)-1)*2 + j1;
                lokindex1 = (i1-1)*2 + j1;
                
                b(index1) = b(index1) + bei(lokindex1);
            end
            
        end
    end
end
