function [x,e,I1,I2,xindex] = diskret_ram(a,b,c,d,h)

% [x,e,I1,I2,xindex] = diskret_ram(a,b,c,d,h)
%          Funkce diskretizuje ram o vnejsich rozmerech a x b
%          se symetricky umistenym oknem o rozmerech c x d
%          s diskretizacnim krokem h.
%          x je vektor uzlovych souranic.
%          e jsou trojuhelnikove elementy = trojice indexu uzlu.
%          I1 je Dirichletova cast hranice, tj. indexy uzlu Gamma_1,
%          coz je spodni a horni strana vnejsiho obvodu.
%          I2 je Neumannova cast hranice, tj. indexy uzlu Gamma_2,
%          coz jsou vsechny ostatni strany vnejsiho i vnitrniho obvodu.
%          xindex je pole indexu o velikosti 2 x max(size(x)),
%          ktere urcuje indexy (i,j) uzlu x v ramci obdelnikove
%          diskretizace.

x1 = -a/2:h:a/2;
x2 = -b/2:h:b/2;

nx1 = max(size(x1));
nx2 = max(size(x2));

rx1 = (a-c)/(2*h) + 1;
mx1 = nx1 - (a-c)/(2*h);
rx2 = (b-d)/(2*h) + 1;
mx2 = nx2 - (b-d)/(2*h);

x = [];
e = [];
I1 = [];
I2 = [];
index = 1;

xindex = [];

% seznam uzlu a elementu
for i=1:nx1
    for j=1:nx2
        if i>rx1 & i<mx1 & j>rx2 & j<mx2
            continue;
        end
        
        x = [x [x1(i);x2(j)]];
        
        xindex = [xindex [i;j]];
        
        if ((i<rx1 | (i>=mx1 & i<nx1)) & j<nx2) | (i==rx1 & j<rx2) | (i==mx1-1 & j>=mx2 & j<nx2)
            e = [ e ; [index index+nx2 index+nx2+1] ; [index index+nx2+1 index+1] ];
        end
        
        if ((i>rx1 & i<mx1-1) & (j<rx2 | (j>=mx2 & j<nx2))) | (i==rx1 & j>=mx2 & j<nx2) | (i==mx1-1 & j<rx2)
            e = [ e ; [index index+2*rx2 index+2*rx2+1] ; [index index+2*rx2+1 index+1] ];
        end
        
        if i==1 | i==nx1 | ((i==rx1 | i==mx1) & j>=rx2 & j<=mx2) & (i>=rx1 & i<=mx1 & (j==rx2 | j==mx2))
            I2 = [I2;index];
        end
        
        if j==1 | j==nx2
            I1 = [I1;index];
        end
        
        index = index + 1;
    end
end

% pocet uzlu
n = size(x,2);

% pocet elementu
ne = size(e,1);
